Coronavirus Dashboard
~~~~~~~~~~~~~~~~~~~~~

This project contains dashboard(s) and other visualizations to monitor the outbreak.

Currently includes:

* A dashboard that detects hotspots based on growth (not total cases) and maps them.

Uses third-party data:

* Coronavirus data from the New York Times.

This is an experimental project. The numbers may be wrong. It should not be relied 
on for any decision making without additional review.

Installation
~~~~~~~~~~~~

:: 

    pip install corona-dashboard


Usage
~~~~~

::

    corona-dashboard

License and Acknowledgment
~~~~~~~~~~~~~~~~~~~~~~~~~~

Apache 2. See LICENSE file for details.

A project of `B.Next <https://www.bnext.org/>`_.